@@ -24,7 +24,7 @@ class Config:
                 raise FileNotFoundError(f"PCC config file {configfile} does not exist!")
 
     def check(self):
-        checks = ["avgr", "fz", "t", "combo", "std", "norm", "chunk_idx"]
+        checks = ["avgr", "fz", "t", "combo", "std", "norm", "chunk_idx", "type"]
         return all(list(map(os.path.exists, [self.config[key] for key in checks])))
 
     def get(self, key):
